﻿using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.DataPresenter.Events;
using Infragistics.Windows.Reporting;
using System;
using System.Collections;
using System.Diagnostics;
using System.Windows;
using Infragistics.Documents.Excel;
using Infragistics.Windows.DataPresenter.ExcelExporter;
using Infragistics.Windows.DataPresenter.WordWriter;

namespace XamGridWPFReporting
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }
        void xamDataGrid1_AssigningFieldLayoutToItem(object sender, AssigningFieldLayoutToItemEventArgs e)
        {
            e.FieldLayout = ((Infragistics.Windows.DataPresenter.DataPresenterBase)(sender)).FieldLayouts[0];

        }

        private void xamDataGrid1_DataContextChanged(object sender, DependencyPropertyChangedEventArgs e)
        {
            XamTreeGrid xamDataGrid = (XamTreeGrid)sender;

            InitFieldLayout(xamDataGrid);
            ResizeColumns(xamDataGrid);
        }

        void ResizeColumns(XamTreeGrid xamDataGrid, double windowWidth = 0)
        {
            if (windowWidth == 0)
            {
                if (Application.Current.MainWindow.WindowState == WindowState.Maximized)
                    windowWidth = System.Windows.SystemParameters.PrimaryScreenWidth - 180;
                else
                    windowWidth = Application.Current.MainWindow.Width - 180;
            }

            int numbersOfCol = 0;
            foreach (var f in xamDataGrid.FieldLayouts[0].Fields)
                if (f.Visibility == Visibility.Visible)
                    numbersOfCol++;

            double nameFieldWidth;
            if (windowWidth < 1000)
                nameFieldWidth = 175;
            else if (windowWidth < 1500)
                nameFieldWidth = 225;
            else
                nameFieldWidth = 300;

            int minColWidth = 70;
            int maxColWidth = 150;

            double colWidth = Math.Min(maxColWidth, Math.Max(minColWidth, (windowWidth - nameFieldWidth) / (numbersOfCol - 2)));

            for (int i = 0; i < xamDataGrid.FieldLayouts.Count; i++)
            {
                xamDataGrid.FieldLayouts[i].Fields[2].Width = new FieldLength(nameFieldWidth);
                //xamDataGrid.FieldLayouts[i].Fields["Name"].Width = new FieldLength(nameFieldWidth);
                //xamDataGrid.FieldLayouts[i].Fields["Name"].FixedLocation = FixedFieldLocation.FixedToNearEdge; //freeze the first column

                try
                {
                    foreach (Field field in xamDataGrid.FieldLayouts[i].Fields)
                    {
                        if (field.Name == "Blank")
                        {
                            field.Width = new FieldLength(15); // the blank column for variance reports
                            field.Label = "";
                        }
                    }
                }
                catch
                {
                }

                xamDataGrid.FieldLayouts[i].FieldSettings.Width = new FieldLength(colWidth);
            }
        }
        private void InitFieldLayout(XamTreeGrid xamDataGrid)
        {
            //FieldLayout f = xamDataGrid.FieldLayouts[0];
            xamDataGrid.FieldLayouts.Clear();
            //xamDataGrid.FieldLayouts.Add(f);

            /*  if (xamDataGrid == xamDataGridHeader)
              {
                  xamDataGrid.FieldLayouts.Add(grdReport.Resources["header"] as FieldLayout);
                  xamDataGrid.FieldLayouts[0].Key = "header";
              }
              else
              {*/
            xamDataGrid.FieldLayouts.Add(grdReport.Resources["master"] as FieldLayout);
            xamDataGrid.FieldLayouts[0].Key = "master";
            //}

            xamDataGrid.DataSource = (IEnumerable)xamDataGrid.DataContext;

            xamDataGrid.FieldLayoutSettings.ExpansionIndicatorDisplayMode = ExpansionIndicatorDisplayMode.CheckOnDisplay;
            xamDataGrid.Records.ExpandAll(true);
        }
        private void Button_Click(object sender, RoutedEventArgs e)
        {
            //double pageSize = 19;
            //double pageNum = 1;
            //double totalPages = xamGrid.Rows.Count / pageSize;

            // xamGrid.ScrollCellIntoView(xamGrid.Rows[0].Cells[0]);


            Report objReport = new Report();

            objReport.Sections.Add(new EmbeddedVisualReportSection(xamGrid));

            objReport.ReportSettings.PageOrientation = PageOrientation.Landscape;
            objReport.ReportSettings.RepeatType = RepeatType.PageBreak;
            objReport.ReportSettings.HorizontalPaginationMode = HorizontalPaginationMode.Scale;

            objReport.ReportSettings.Margin = new Thickness(12, 0, 12, 0);


            objReport.PageHeader = "Header";

            //objReport.Print(true, true);

            //pageNum += 1.0;
            //double scrollToIndex = Math.Min(pageSize * pageNum - 1.0, xamGrid.Rows.Count - 1.0);
            //xamGrid.ScrollCellIntoView(xamGrid.Rows[(int)scrollToIndex].Cells[0]);

            XamReportPreview XamReportPreview1 = new XamReportPreview();
            XamReportPreview1.GeneratePreview(objReport, false, false);

            Window view = new Window();
            view.Title = "Print Preview";

            view.Content = XamReportPreview1;
            view.Show();
            view.Activate();


        }
        private void Excel_Export_Click(object sender, RoutedEventArgs e)
        {
            Workbook workbook = new Workbook(WorkbookFormat.Excel2007);

            Worksheet ws1 = workbook.Worksheets.Add("Report Sheet");

            DataPresenterExcelExporter exporter = new DataPresenterExcelExporter();

            DataPresenterWordWriter wordExporter = new DataPresenterWordWriter();
            wordExporter.Export(xamGrid, @"..\..\ExportGrid.docx");

            exporter.Export(xamGrid, ws1,
                new ExportOptions()
                {
                    ExcludeFieldSettings = false,
                    ExcludeFieldLayoutSettings = false,
                    ExcludeExpandedState = false
                });

            workbook.Save(@"..\..\ExportGrid.xlsx");



            Process.Start(@"..\..\ExportGrid.xlsx");


        }
    }
}
